pub struct OAuth2 {
pub enabled: bool,
pub issuer_url: Option<String>,
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub scopes: Vec<String>,
pub auto_provision_users: bool,
pub admin_group_claim: Option<String>,
pub admin_group_value: Option<String>,
pub read_only_group_claim: Option<String>,
pub read_only_group_value: Option<String>,
pub button_text: String,
}Expand description
OAuth2/OpenID Connect authentication configuration
Fields
enabled: boolEnable OAuth2/OIDC authentication
issuer_url: Option<String>OIDC issuer URL (discovery URL, e.g., <https://authentik.example.com/application/o/kellnr/>)
client_id: Option<String>OAuth2 client ID
client_secret: Option<String>OAuth2 client secret (prefer setting via KELLNR_OAUTH2__CLIENT_SECRET env var)
scopes: Vec<String>OAuth2 scopes to request (default: ["openid", "profile", "email"])
auto_provision_users: boolAutomatically create local user accounts for new OAuth2 users
admin_group_claim: Option<String>Claim name to check for admin group membership (e.g., “groups”)
admin_group_value: Option<String>Value in the admin group claim that grants admin privileges (e.g., “kellnr-admins”)
read_only_group_claim: Option<String>Claim name to check for read-only group membership (e.g., “groups”)
read_only_group_value: Option<String>Value in the read-only group claim that grants read-only access (e.g., “kellnr-readonly”)
Text displayed on the OAuth2 login button
Implementations